import axios from 'axios';
import { ErrorMessage } from 'formik';
import { toast } from 'react-toastify';
import setAuthToken from '../../helpers/setAuthToken';
import { Apiurl } from '../../helpers/URL';

// Types
const REGISTER_SUCCESS = 'REGISTER_SUCCESS';
const REGISTER_FAIL = 'REGISTER_FAIL';
const LOGIN_SUCCESS = 'LOGIN_SUCCESS';
const LOGIN_FAIL = 'LOGIN_FAIL';
const USER_LOADED = 'USER_LOADED'
const AUTH_ERROR = 'AUTH_ERROR'
const LOGOUT = 'LOGOUT'
const SET_LOADING = 'SET_LOADING'
const CLEAR_ERROR = 'CLEAR_ERROR'
// Intial State
const intialState = { token: sessionStorage.getItem('token'), isAuthenticated: null, loading: true, user: null, };
// userdata: sessionStorage.getItem('user'),

// Reducers
export default function (state = intialState, action) {
    const { type, payload } = action;
    switch (type) {

    case USER_LOADED:
        return {
            ...state, user: payload, isAuthenticated: true, loading: false
        }
        case REGISTER_SUCCESS:
            return {
                ...state, ...payload, isAuthenticated: true, loading: false,
            };
        case LOGIN_SUCCESS:
            // // Set Token in sessionStorage
            sessionStorage.setItem('token', payload.user.token);
            sessionStorage.setItem('username', payload.user.username);
            sessionStorage.setItem('ip', payload.user.ip);
            sessionStorage.setItem('role', payload.user.type);
            return {
                ...state, ...payload, isAuthenticated: true, loading: false,
            };
        case SET_LOADING:
            return {
                ...state, loading: true
            }
            case REGISTER_FAIL:
            // Remove Token in localstorage
            // sessionStorage.removeItem('token');
            return {
                ...state, error: null, isAuthenticated: false, loading: false,
            };
            case LOGIN_FAIL:
            case AUTH_ERROR:
            case LOGOUT:
                // Remove Token in sessionStorage
            sessionStorage.removeItem('token');
            // sessionStorage.removeItem('username', payload.user.username);
            // sessionStorage.removeItem('ip', payload.user.ip);
            // sessionStorage.setItem('role', payload.user.type);
                return {
                    ...state, token: null, isAuthenticated: false, loading: false, user: null
                };
            
            case CLEAR_ERROR:
                return {
                    ...state,
                    errors: null
            };
            default:
                return state;
    }
}

// Actions

// export function clearError() {
//     return {
//       type: CLEAR_ERROR
//     };
// }

export const clearError = () => dispatch => {
    dispatch({ type: CLEAR_ERROR })
}

export const loadUser = () => async (dispatch) => {
    if (sessionStorage.token) { setAuthToken(sessionStorage.token) }

    try {
        const res = await axios.post(`${Apiurl}/user/auth`);
        dispatch({ type: USER_LOADED, payload: res.data })
        // if (res.data.status === 200) return window.history.push('/');
    } catch (error) {
        console.log("error", error.response)
        dispatch({ type: AUTH_ERROR })
    }
}
export const register = ({ username, name, mobile, email, password }) => async (dispatch) => {
    // Config header for axios
    const config = {
        headers: { 'Content-Type': 'application/json', },
        crossDomain: true,
        'Access-Control-Allow-Origin': '*'
    };

    // Set body
    const body = JSON.stringify({ username, name, mobile, email, password });
    
    dispatch({ type: SET_LOADING })
    try {
        // Response 
        const res = await axios.post(`${Apiurl}/user/signup`, body, config)
        dispatch({ type: REGISTER_SUCCESS, payload: res.data })
        dispatch(loadUser())
    } catch (err) {
        const errors = err.response.data.errors
        if (errors) { errors.forEach(error => toast.error(error.msg)) }
        dispatch({ type: REGISTER_FAIL })
        console.log("REGISTER_FAIL", REGISTER_FAIL)
    }
};

export const login = ({ username, password }) => async (dispatch) => {
    // Config header for axios
    const config = { headers: { 'Content-Type': 'application/json', }, };
    // Set body
    const body = JSON.stringify({ username, password });
    dispatch({ type: SET_LOADING })
    try {
        // Response 
        const res = await axios.post(`${Apiurl}/user/auth`, body, config)
        dispatch({ type: LOGIN_SUCCESS, payload: res.data })
        dispatch(loadUser())
        console.log(res.data)
    } catch (err) {
        // const errors = err.response.data
        const errors = err && err.response && err.response.data
        if (errors) { errors.forEach(error => toast.error(error.msg)) }
        dispatch({ type: LOGIN_FAIL })
    }
};

export const logout = () => dispatch => {
    dispatch({ type: LOGOUT })
}