import React, { useEffect, useState } from 'react';
import { toast, ToastContainer } from 'react-toastify';
import { connect, useDispatch, useSelector } from 'react-redux';
import Button from '../../components/buttons/button.component';
import FormInput from '../../components/inputs/form.input.component';
import { login, clearError } from '../../data/reducers/auth';
import { Redirect, useHistory } from 'react-router-dom';


import Navbarlogin from '../../components/navbarlogin/Navbarlogin'
import Footers from '../../components/footer/Footers'
import "./login.css"

const Login = ({ login, isAuth, isLoading, user, clearError  }) => {
	const history = useHistory();
	const error = useSelector(state => state.auth.reason)
	const dispatch  = useDispatch()
	useEffect(() => {
		if(error) {
			console.log(toast.error(error))
				// dispatch(clearError)
		}
	}, [error])
	
	const [data, setData] = useState({
		username: '',
		password: '',
	});

	const { username, password } = data;

	const handleChange = (name) => (event) => {
		setData({ ...data, [name]: event.target.value });
	};

	const onSubmit = async (e) => {
		e.preventDefault();
		if (error) {
			toast.error('Incorrect email or password')
		} else if (!username || !password) {
			toast.error('Incorrect email or password')
		} else {
			login({ username, password });
			// console.log('Hi', toast.success(`welcome ${username}` + history.push('/mall')))
		}
	};

	if (isAuth && user) {
		const { username } = user;
		toast.success(`welcome ${username}`);
		if (username) history.push('/mall');
	}


  return (
	<><ToastContainer />
	<div style={{ backgroundImage: `url("https://wallpapercave.com/wp/wp3252152.jpg")` }}>
	<Navbarlogin />
	<form onSubmit={onSubmit}>
		<div className="max-w-md mx-auto bg-white shadow-xl rounded-xl m-12 relative zindex-5 bgimg">
			<div className="flex justify-between p-4 pt-4 m-2">
				<h className="text-3xl font-semibold">LOGIN</h>
				<div className="text-right">
					<small>New to Payungg ?</small><br />
					<a href='#/register' className="font-bold text-blue-700" alt="" >SIGN UP</a>
				</div>
			</div>
			<div className="bg-gray-200 pt-8 pb-16">
				<div className="text-center text-gray-600 mb-6">Or sign in with Email & Password</div>
				<div className="w-4/5 mx-auto">
					<div className="flex items-center bg-white rounded shadow-md mb-4">
						<span className="px-3">
							<svg className="fill-current text-gray-500 w-4 h-4" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 20 20"><path d="M18 2a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V4c0-1.1.9-2 2-2h16zm-4.37 9.1L20 16v-2l-5.12-3.9L20 6V4l-10 8L0 4v2l5.12 4.1L0 14v2l6.37-4.9L10 14l3.63-2.9z"/></svg>
						</span>
						<FormInput placeholder='username' value={username} handleChange={handleChange('username')} type='username' />
					</div>
					<div className="flex items-center bg-white rounded shadow-md mb-4">
						<span className="px-3">
							<svg className="fill-current text-gray-500 w-4 h-4" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 20 20"><path d="M4 8V6a6 6 0 1 1 12 0h-3v2h4a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2v-8c0-1.1.9-2 2-2h1zm5 6.73V17h2v-2.27a2 2 0 1 0-2 0zM7 6v2h6V6a3 3 0 0 0-6 0z"/></svg>
						</span>
						<FormInput className="w-full focus:outline-none m-0" placeholder='******' value={password} handleChange={handleChange('password')} type='password' />
					</div>
					{/* <div className="mb-4">
						<input type="checkbox" name="remember" className="mr-1" />
						<label for="remember" className="text-sm text-gray-600">Remember me</label>
					</div> */}
					{!isLoading && (
					<Button
						title='Login'
						moreStyle='bg-blue-600 block sm:mx-auto md:w-3/4 text-white text-sm uppercase rounded-full shadow-md px-6 py-2'
						type='submit'
					/>
					)}
					{/* <button className="bg-blue-600 block sm:mx-auto md:w-3/4 text-white text-sm uppercase rounded-full shadow-md px-6 py-2" type='submit'>Sign in</button> */}
					<div className="w-full text-center">
						<p><small className="">
						<a href="#/forgotpass" alt="forgot-pass" >Forgot Password?</a>
						</small></p>
					</div>
				</div>
			</div>
			{/* <div className="text-center text-gray-600 py-4">Submit</div>
			<div className="flex justify-center mb-10 py-4">
				<button className="flex items-center bg-gray-100 shadow-md border border-gray-200 rounded px-4 py-2 mr-2">
					<svg className="fill-current text-gray-600 w-4 h-4 mr-2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 20 20"><path d="M10 20a10 10 0 1 1 0-20 10 10 0 0 1 0 20zM7 6v2a3 3 0 1 0 6 0V6a3 3 0 1 0-6 0zm-3.65 8.44a8 8 0 0 0 13.3 0 15.94 15.94 0 0 0-13.3 0z"/></svg>
					<div className="text-indigo-700">Facebook</div>
				</button>
				<button className="flex items-center bg-gray-100 shadow-md border border-gray-200 rounded px-4 py-2 mr-2">
					<svg className="fill-current text-gray-600 w-4 h-4 mr-2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 20 20"><path d="M10 20a10 10 0 1 1 0-20 10 10 0 0 1 0 20zM7 6v2a3 3 0 1 0 6 0V6a3 3 0 1 0-6 0zm-3.65 8.44a8 8 0 0 0 13.3 0 15.94 15.94 0 0 0-13.3 0z"/></svg>
					<div className="text-indigo-700">Gmail</div>
				</button>
			</div> */}
		</div>
	</form>
	<Footers />
	</div>
	</>
  );
};

const mapToStateProps = (state) => ({
  isAuth: state.auth.isAuthenticated,
  isLoading: state.auth.loading,
  user: state.auth.user,
});
export default connect(mapToStateProps, { login })(Login);
