import React from "react";
import { CountdownCircleTimer } from "react-countdown-circle-timer";
// import "./styles.css";

const minuteSeconds = 60;
const hourSeconds = 3600;
const daySeconds = 86400;

const timerProps = {
  isPlaying: true,
  size: 110,
  strokeWidth: 3
};

const renderTime = (dimension, time) => {
  return (
    <div className="time-wrapper">
      <div className="time">{time}</div>
      <div>{dimension}</div>
    </div>
  );
};

const getTimeSeconds = (time) => (minuteSeconds - time) | 0;
const getTimeMinutes = (time) => ((time % hourSeconds) / minuteSeconds) | 0;
const getTimeHours = (time) => ((time % daySeconds) / hourSeconds) | 0;
const getTimeDays = (time) => (time / daySeconds) | 0;

export default function PromoTime() {
  const stratTime = Date.now() / 1000; // use UNIX timestamp in seconds
  const endTime = stratTime + 243248; // use UNIX timestamp in seconds

  const remainingTime = endTime - stratTime;
  const days = Math.ceil(remainingTime / daySeconds);
  const daysDuration = days * daySeconds;

  return (
    <div className="hidden sm:hidden lg:flex text-center self-center items-center font-bold md:text-lg" style={{zoom: "0.8"}}>
        <img className="block h-48 w-auto" src="assets/img/megasales.png" alt="Workflow" />
          
        <CountdownCircleTimer {...timerProps} colors={[["#C53030"]]} duration={daysDuration} initialRemainingTime={remainingTime} >
            {({ elapsedTime }) =>
                renderTime("days", getTimeDays(daysDuration - elapsedTime))
            }
        </CountdownCircleTimer>
        <CountdownCircleTimer {...timerProps} colors={[["#C53030"]]} duration={daySeconds} initialRemainingTime={remainingTime % daySeconds} onComplete={(totalElapsedTime) => [ remainingTime - totalElapsedTime > hourSeconds ]} >
            {({ elapsedTime }) =>
                renderTime("hours", getTimeHours(daySeconds - elapsedTime))
            }
        </CountdownCircleTimer>
        <CountdownCircleTimer {...timerProps} colors={[["#C53030"]]} duration={hourSeconds} initialRemainingTime={remainingTime % hourSeconds} onComplete={(totalElapsedTime) => [ remainingTime - totalElapsedTime > minuteSeconds ]} >
            {({ elapsedTime }) =>
                renderTime("minutes", getTimeMinutes(hourSeconds - elapsedTime))
            }
        </CountdownCircleTimer>
        <CountdownCircleTimer {...timerProps} colors={[["#218380"]]} duration={minuteSeconds} initialRemainingTime={remainingTime % minuteSeconds} onComplete={(totalElapsedTime) => [ remainingTime - totalElapsedTime > 0 ]} >
            {({ elapsedTime }) =>
                renderTime("seconds", getTimeSeconds(elapsedTime))
            }
        </CountdownCircleTimer>
    </div>
  );
}
